==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/ka.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "New text file",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded or file size exceeds maximum of %s" : "No file uploaded or file size exceeds maximum of %s",
    "Text" : "Text",
    "Translate" : "Translate",
    "Delete task" : "Delete task",
    "Guest" : "Guest",
    "guest" : "guest",
    "Saving …" : "Saving …",
    "Saved" : "Saved",
    "Formatting help" : "Formatting help",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Enter" : "Enter",
    "Shift" : "Shift",
    "Ctrl" : "Ctrl",
    "Quoted text" : "Quoted text",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Translate from" : "Translate from",
    "Select language" : "Select language",
    "to" : "to",
    "Replace" : "Replace",
    "Source code" : "Source code",
    "Undo" : "Undo",
    "Headings" : "Headings",
    "Info" : "Info",
    "Warning" : "Warning",
    "Command" : "Command",
    "Formatting" : "Formatting",
    "Smart picker" : "Smart picker",
    "Edit" : "Edit",
    "Link copied" : "Link copied"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/ka.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "New text file",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded or file size exceeds maximum of %s" : "No file uploaded or file size exceeds maximum of %s",
    "Text" : "Text",
    "Translate" : "Translate",
    "Delete task" : "Delete task",
    "Reload" : "Reload",
    "Guest" : "Guest",
    "guest" : "guest",
    "Saving …" : "Saving …",
    "Saved" : "Saved",
    "Formatting help" : "Formatting help",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Enter" : "Enter",
    "Shift" : "Shift",
    "Ctrl" : "Ctrl",
    "Quoted text" : "Quoted text",
    "Save changes" : "Save changes",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "Select file or folder to link to" : "Select file or folder to link to",
    "Translate from" : "Translate from",
    "Select language" : "Select language",
    "to" : "to",
    "Replace" : "Replace",
    "Copy code block" : "Copy code block",
    "Source code" : "Source code",
    "Undo" : "Undo",
    "Headings" : "Headings",
    "Info" : "Info",
    "Warning" : "Warning",
    "Command" : "Command",
    "Formatting" : "Formatting",
    "Smart picker" : "Smart picker",
    "Edit" : "Edit"
},
"nplurals=2; plural=(n!=1);");
